package com.os.mes.api.service.impl;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.PropertyNamingStrategy;
import com.os.common.utils.StringUtils;
import com.os.mes.api.domain.*;
import com.os.mes.api.service.IERPPortService;
import com.os.mes.api.utils.ApiUtils;
import com.os.mes.api.utils.ERPConstants;
import com.os.mes.base.domain.BaseStaffInfo;
import com.os.mes.base.service.IBaseStaffInfoService;
import com.os.mes.prod.domain.ProdOrderDetail;
import com.os.mes.prod.service.IProdOrderInfoService;
import com.os.mes.prod.service.impl.ProdOrderInfoServiceImpl;
import com.os.mes.record.domain.RecordStaffSalary;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.math.RoundingMode;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;


/**
 * ERP接口Service业务层处理
 *
 * @author Yinq
 * @date 2024-05-10
 */
@Service
public class ERPPortServiceImpl implements IERPPortService {
    private static final Logger logger = LoggerFactory.getLogger(ERPPortServiceImpl.class);

    @Autowired
    private IProdOrderInfoService orderInfoService;

    @Autowired
    private IBaseStaffInfoService staffInfoService;

    /**
     * 获取ERP订单接口
     *
     * @param paramDto
     * @return
     */
    @Override
    public List<ProdOrderDetail> getERPOrderData(ERPParamDto paramDto) {
        List<ProdOrderDetail> resultList = new ArrayList<>();
        String requestParam = null;
        String result = null;
        try {
            // 创建ObjectMapper实例 对象转JSON字符串
            ObjectMapper objectMapper = new ObjectMapper();
            objectMapper.setPropertyNamingStrategy(PropertyNamingStrategy.UPPER_CAMEL_CASE);
            requestParam = objectMapper.writeValueAsString(paramDto);
            result = ApiUtils.sendERPHttpPost(ERPConstants.ERP_URL, requestParam);
//            result = "{\"Successful\":true,\"ErrorMessage\":null,\"Logined\":false,\"ReturnData\":{\"totle\":3,\"data\":[{\"BeltWidth\":1600,\"BeltClothLayer\":5,\"BeltRequiredLength\":250,\"GluingRequiredThickness\":6,\"LowerGlueRequiredThickness\":2,\"ProductionGluingThickness\":4.5,\"UpperBufferAdhesiveThickness\":1.5,\"ProductionLowerGlueThickness\":1.2,\"LowerBufferAdhesiveThickness\":0.8,\"ClothGlueThickness\":1.3,\"SmallClothFabricLayer\":0,\"SmallClothThickness\":0,\"IsNeedThicken\":\"否\",\"EachLayerThickenThickness\":0,\"ExtraThickeningThickness\":0,\"TotalProductionThickness\":14.5,\"AdditionalThickness\":0.5,\"RecommendedShimThickness\":13.5,\"SemiFinishedProductWidth\":1560,\"RollingProductionMeters\":251.8,\"RecommendedPadWidth\":1794,\"BigFabricManufacturer\":\"安徽旌德\",\"FabricSpecifications\":{\"MaterialNo\":\"WLFB0066\",\"MaterialName\":\"EE300N\",\"MaterialSpecification\":\"EE300N\",\"MaterialLargeCategories\":\"帆布类\",\"MaterialSmallCategories\":\"EE-N轻型浸胶帆布\"},\"EstimatedFabricUsage\":1259,\"ClothWidth\":1600,\"ClothWeight\":1752.528,\"SmallFabricSpecificationsDic\":{\"MaterialNo\":\"\",\"MaterialName\":\"\",\"MaterialSpecification\":\"\",\"MaterialLargeCategories\":\"\",\"MaterialSmallCategories\":\"\"},\"SmallClothWidth\":1300,\"SmallClothUsage\":0,\"SmallClothWeight\":0,\"GluingProcess\":\"双胶\",\"UpperLowerGlue\":{\"MaterialList_1\":[{\"MaterialNo\":\"WLXJ0008\",\"Material\":{\"MaterialNo\":\"WLXJ0008\",\"MaterialName\":\"天然胶\",\"MaterialSpecification\":\"天然胶\",\"MaterialLargeCategories\":\"橡胶类\",\"MaterialSmallCategories\":\"天然橡胶\"},\"EnterSecondLaneWeight\":47.6607},{\"MaterialNo\":\"WLXJ0011\",\"Material\":{\"MaterialNo\":\"WLXJ0011\",\"MaterialName\":\"丁苯-1502\",\"MaterialSpecification\":\"SBR1502\",\"MaterialLargeCategories\":\"橡胶类\",\"MaterialSmallCategories\":\"丁苯橡胶\"},\"EnterSecondLaneWeight\":27.1485},{\"MaterialNo\":\"WLXJ0005\",\"Material\":{\"MaterialNo\":\"WLXJ0005\",\"MaterialName\":\"顺丁橡胶BR9000\",\"MaterialSpecification\":\"BR9000\",\"MaterialLargeCategories\":\"橡胶类\",\"MaterialSmallCategories\":\"顺丁橡胶\"},\"EnterSecondLaneWeight\":21.1155},{\"MaterialNo\":\"WLXJ0004\",\"Material\":{\"MaterialNo\":\"WLXJ0004\",\"MaterialName\":\"普通母胶9\",\"MaterialSpecification\":\"普通母胶9\",\"MaterialLargeCategories\":\"橡胶类\",\"MaterialSmallCategories\":\"再生胶\"},\"EnterSecondLaneWeight\":27.1485},{\"MaterialNo\":\"XJZJ0029\",\"Material\":{\"MaterialNo\":\"XJZJ0029\",\"MaterialName\":\"氧化锌\",\"MaterialSpecification\":\"氧化锌\",\"MaterialLargeCategories\":\"橡胶助剂\",\"MaterialSmallCategories\":\"化合物\"},\"EnterSecondLaneWeight\":3.837},{\"MaterialNo\":\"XJZJ0028\",\"Material\":{\"MaterialNo\":\"XJZJ0028\",\"MaterialName\":\"硬脂酸\",\"MaterialSpecification\":\"硬脂酸\",\"MaterialLargeCategories\":\"橡胶助剂\",\"MaterialSmallCategories\":\"硫化活性剂\"},\"EnterSecondLaneWeight\":2.4132},{\"MaterialNo\":\"XJZJ0082\",\"Material\":{\"MaterialNo\":\"XJZJ0082\",\"MaterialName\":\"橡胶防老剂RD(TMQ)\",\"MaterialSpecification\":\"防老剂RD(TMQ)\",\"MaterialLargeCategories\":\"橡胶助剂\",\"MaterialSmallCategories\":\"橡胶防老剂\"},\"EnterSecondLaneWeight\":1.9185},{\"MaterialNo\":\"XJZJ0092\",\"Material\":{\"MaterialNo\":\"XJZJ0092\",\"MaterialName\":\"L-6023橡胶特种防护蜡\",\"MaterialSpecification\":\"L-6023\",\"MaterialLargeCategories\":\"橡胶助剂\",\"MaterialSmallCategories\":\"固体蜡\"},\"EnterSecondLaneWeight\":1.9306},{\"MaterialNo\":\"XJZJ0031\",\"Material\":{\"MaterialNo\":\"XJZJ0031\",\"MaterialName\":\"古马隆\",\"MaterialSpecification\":\"古马隆\",\"MaterialLargeCategories\":\"橡胶助剂\",\"MaterialSmallCategories\":\"化合物\"},\"EnterSecondLaneWeight\":4.8264},{\"MaterialNo\":\"XJZJ0062\",\"Material\":{\"MaterialNo\":\"XJZJ0062\",\"MaterialName\":\"炭黑N330\",\"MaterialSpecification\":\"炭黑N330\",\"MaterialLargeCategories\":\"橡胶助剂\",\"MaterialSmallCategories\":\"橡胶补强剂\"},\"EnterSecondLaneWeight\":57.5548},{\"MaterialNo\":\"XJZJ0013\",\"Material\":{\"MaterialNo\":\"XJZJ0013\",\"MaterialName\":\"2#橡胶油\",\"MaterialSpecification\":\"2#橡胶油\",\"MaterialLargeCategories\":\"橡胶助剂\",\"MaterialSmallCategories\":\"液体油\"},\"EnterSecondLaneWeight\":9.5925},{\"MaterialNo\":\"\",\"Material\":{\"MaterialNo\":\"\",\"MaterialName\":\"\",\"MaterialSpecification\":\"\",\"MaterialLargeCategories\":\"\",\"MaterialSmallCategories\":\"\"},\"EnterSecondLaneWeight\":0},{\"MaterialNo\":\"\",\"Material\":{\"MaterialNo\":\"\",\"MaterialName\":\"\",\"MaterialSpecification\":\"\",\"MaterialLargeCategories\":\"\",\"MaterialSmallCategories\":\"\"},\"EnterSecondLaneWeight\":0}],\"MaterialList_2\":[{\"MaterialNo\":\"XJZJ0070\",\"Material\":{\"MaterialNo\":\"XJZJ0070\",\"MaterialName\":\"促进剂CBS(CZ)\",\"MaterialSpecification\":\"促进剂CBS(CZ)\",\"MaterialLargeCategories\":\"橡胶助剂\",\"MaterialSmallCategories\":\"橡胶促进剂\"},\"ProductionRequiresWeight\":1.6078},{\"MaterialNo\":\"XJZJ0093\",\"Material\":{\"MaterialNo\":\"XJZJ0093\",\"MaterialName\":\"硫磺\",\"MaterialSpecification\":\"硫磺\",\"MaterialLargeCategories\":\"橡胶助剂\",\"MaterialSmallCategories\":\"矿物质\"},\"ProductionRequiresWeight\":3.514},{\"MaterialNo\":\"\",\"Material\":{\"MaterialNo\":\"\",\"MaterialName\":\"\",\"MaterialSpecification\":\"\",\"MaterialLargeCategories\":\"\",\"MaterialSmallCategories\":\"\"},\"ProductionRequiresWeight\":0},{\"MaterialNo\":\"\",\"Material\":{\"MaterialNo\":\"\",\"MaterialName\":\"\",\"MaterialSpecification\":\"\",\"MaterialLargeCategories\":\"\",\"MaterialSmallCategories\":\"\"},\"ProductionRequiresWeight\":0}],\"AfterPromotionTotalWeight\":208.2362},\"UpperLowerGlueCoefficient\":1.142,\"UpperLowerGlueUsage\":2070.4,\"LowerGlue\":{\"MaterialList_1\":[{\"MaterialNo\":\"WLXJ0008\",\"Material\":{\"MaterialNo\":\"WLXJ0008\",\"MaterialName\":\"天然胶\",\"MaterialSpecification\":\"天然胶\",\"MaterialLargeCategories\":\"橡胶类\",\"MaterialSmallCategories\":\"天然橡胶\"},\"EnterSecondLaneWeight\":69.6848},{\"MaterialNo\":\"WLXJ0005\",\"Material\":{\"MaterialNo\":\"WLXJ0005\",\"MaterialName\":\"顺丁橡胶BR9000\",\"MaterialSpecification\":\"BR9000\",\"MaterialLargeCategories\":\"橡胶类\",\"MaterialSmallCategories\":\"顺丁橡胶\"},\"EnterSecondLaneWeight\":12.204},{\"MaterialNo\":\"\",\"Material\":{\"MaterialNo\":\"\",\"MaterialName\":\"\",\"MaterialSpecification\":\"\",\"MaterialLargeCategories\":\"\",\"MaterialSmallCategories\":\"\"},\"EnterSecondLaneWeight\":0},{\"MaterialNo\":\"WLXJ0004\",\"Material\":{\"MaterialNo\":\"WLXJ0004\",\"MaterialName\":\"普通母胶9\",\"MaterialSpecification\":\"普通母胶9\",\"MaterialLargeCategories\":\"橡胶类\",\"MaterialSmallCategories\":\"再生胶\"},\"EnterSecondLaneWeight\":67.122},{\"MaterialNo\":\"XJZJ0029\",\"Material\":{\"MaterialNo\":\"XJZJ0029\",\"MaterialName\":\"氧化锌\",\"MaterialSpecification\":\"氧化锌\",\"MaterialLargeCategories\":\"橡胶助剂\",\"MaterialSmallCategories\":\"化合物\"},\"EnterSecondLaneWeight\":2.4591},{\"MaterialNo\":\"XJZJ0028\",\"Material\":{\"MaterialNo\":\"XJZJ0028\",\"MaterialName\":\"硬脂酸\",\"MaterialSpecification\":\"硬脂酸\",\"MaterialLargeCategories\":\"橡胶助剂\",\"MaterialSmallCategories\":\"硫化活性剂\"},\"EnterSecondLaneWeight\":1.6414},{\"MaterialNo\":\"XJZJ0092\",\"Material\":{\"MaterialNo\":\"XJZJ0092\",\"MaterialName\":\"L-6023橡胶特种防护蜡\",\"MaterialSpecification\":\"L-6023\",\"MaterialLargeCategories\":\"橡胶助剂\",\"MaterialSmallCategories\":\"固体蜡\"},\"EnterSecondLaneWeight\":1.6414},{\"MaterialNo\":\"XJZJ0082\",\"Material\":{\"MaterialNo\":\"XJZJ0082\",\"MaterialName\":\"橡胶防老剂RD(TMQ)\",\"MaterialSpecification\":\"防老剂RD(TMQ)\",\"MaterialLargeCategories\":\"橡胶助剂\",\"MaterialSmallCategories\":\"橡胶防老剂\"},\"EnterSecondLaneWeight\":1.6414},{\"MaterialNo\":\"XJZJ0031\",\"Material\":{\"MaterialNo\":\"XJZJ0031\",\"MaterialName\":\"古马隆\",\"MaterialSpecification\":\"古马隆\",\"MaterialLargeCategories\":\"橡胶助剂\",\"MaterialSmallCategories\":\"化合物\"},\"EnterSecondLaneWeight\":2.4591},{\"MaterialNo\":\"XJZJ0062\",\"Material\":{\"MaterialNo\":\"XJZJ0062\",\"MaterialName\":\"炭黑N330\",\"MaterialSpecification\":\"炭黑N330\",\"MaterialLargeCategories\":\"橡胶助剂\",\"MaterialSmallCategories\":\"橡胶补强剂\"},\"EnterSecondLaneWeight\":18.8552},{\"MaterialNo\":\"XJZJ0059\",\"Material\":{\"MaterialNo\":\"XJZJ0059\",\"MaterialName\":\"白炭黑\",\"MaterialSpecification\":\"白炭黑\",\"MaterialLargeCategories\":\"橡胶助剂\",\"MaterialSmallCategories\":\"橡胶补强剂\"},\"EnterSecondLaneWeight\":15.9872},{\"MaterialNo\":\"XJZJ0013\",\"Material\":{\"MaterialNo\":\"XJZJ0013\",\"MaterialName\":\"2#橡胶油\",\"MaterialSpecification\":\"2#橡胶油\",\"MaterialLargeCategories\":\"橡胶助剂\",\"MaterialSmallCategories\":\"液体油\"},\"EnterSecondLaneWeight\":1.2204},{\"MaterialNo\":\"XJZJ0024\",\"Material\":{\"MaterialNo\":\"XJZJ0024\",\"MaterialName\":\"SI69(KH-845)\",\"MaterialSpecification\":\"SI69(KH-845)\",\"MaterialLargeCategories\":\"橡胶助剂\",\"MaterialSmallCategories\":\"粘合剂\"},\"EnterSecondLaneWeight\":2.0503},{\"MaterialNo\":\"XJZJ0083\",\"Material\":{\"MaterialNo\":\"XJZJ0083\",\"MaterialName\":\"橡胶防老剂4010NA(IPPD)\",\"MaterialSpecification\":\"防老剂4010NA(IPPD)\",\"MaterialLargeCategories\":\"橡胶助剂\",\"MaterialSmallCategories\":\"橡胶防老剂\"},\"EnterSecondLaneWeight\":0.8177},{\"MaterialNo\":\"XJZJ0118\",\"Material\":{\"MaterialNo\":\"XJZJ0118\",\"MaterialName\":\"二氧化硅微粉\",\"MaterialSpecification\":\"二氧化硅微粉\",\"MaterialLargeCategories\":\"橡胶助剂\",\"MaterialSmallCategories\":\"化合物\"},\"EnterSecondLaneWeight\":6.102},{\"MaterialNo\":\"\",\"Material\":{\"MaterialNo\":\"\",\"MaterialName\":\"\",\"MaterialSpecification\":\"\",\"MaterialLargeCategories\":\"\",\"MaterialSmallCategories\":\"\"},\"EnterSecondLaneWeight\":0}],\"MaterialList_2\":[{\"MaterialNo\":\"XJZJ0093\",\"Material\":{\"MaterialNo\":\"XJZJ0093\",\"MaterialName\":\"硫磺\",\"MaterialSpecification\":\"硫磺\",\"MaterialLargeCategories\":\"橡胶助剂\",\"MaterialSmallCategories\":\"矿物质\"},\"ProductionRequiresWeight\":6.5225},{\"MaterialNo\":\"XJZJ0071\",\"Material\":{\"MaterialNo\":\"XJZJ0071\",\"MaterialName\":\"促进剂MBTS(DM)\",\"MaterialSpecification\":\"促进剂MBTS(DM)\",\"MaterialLargeCategories\":\"橡胶助剂\",\"MaterialSmallCategories\":\"橡胶促进剂\"},\"ProductionRequiresWeight\":0.5244},{\"MaterialNo\":\"XJZJ0070\",\"Material\":{\"MaterialNo\":\"XJZJ0070\",\"MaterialName\":\"促进剂CBS(CZ)\",\"MaterialSpecification\":\"促进剂CBS(CZ)\",\"MaterialLargeCategories\":\"橡胶助剂\",\"MaterialSmallCategories\":\"橡胶促进剂\"},\"ProductionRequiresWeight\":0.9177},{\"MaterialNo\":\"XJZJ0091\",\"Material\":{\"MaterialNo\":\"XJZJ0091\",\"MaterialName\":\"防焦剂CTP\",\"MaterialSpecification\":\"防焦剂CTP\",\"MaterialLargeCategories\":\"橡胶助剂\",\"MaterialSmallCategories\":\"防焦剂\"},\"ProductionRequiresWeight\":0.3933},{\"MaterialNo\":\"\",\"Material\":{\"MaterialNo\":\"\",\"MaterialName\":\"\",\"MaterialSpecification\":\"\",\"MaterialLargeCategories\":\"\",\"MaterialSmallCategories\":\"\"},\"ProductionRequiresWeight\":0}],\"AfterPromotionTotalWeight\":208.986},\"LowerGlueCoefficient\":1.145,\"LowerGlueUsage\":553.557,\"LargeClothGlue\":{\"MaterialList_1\":[{\"MaterialNo\":\"WLXJ0008\",\"Material\":{\"MaterialNo\":\"WLXJ0008\",\"MaterialName\":\"天然胶\",\"MaterialSpecification\":\"天然胶\",\"MaterialLargeCategories\":\"橡胶类\",\"MaterialSmallCategories\":\"天然橡胶\"},\"EnterSecondLaneWeight\":10.478},{\"MaterialNo\":\"WLXJ0011\",\"Material\":{\"MaterialNo\":\"WLXJ0011\",\"MaterialName\":\"丁苯-1502\",\"MaterialSpecification\":\"SBR1502\",\"MaterialLargeCategories\":\"橡胶类\",\"MaterialSmallCategories\":\"丁苯橡胶\"},\"EnterSecondLaneWeight\":31.434},{\"MaterialNo\":\"WLXJ0013\",\"Material\":{\"MaterialNo\":\"WLXJ0013\",\"MaterialName\":\"丁苯-1712\",\"MaterialSpecification\":\"SBR1712\",\"MaterialLargeCategories\":\"橡胶类\",\"MaterialSmallCategories\":\"丁苯橡胶\"},\"EnterSecondLaneWeight\":18.3365},{\"MaterialNo\":\"WLXJ0004\",\"Material\":{\"MaterialNo\":\"WLXJ0004\",\"MaterialName\":\"普通母胶9\",\"MaterialSpecification\":\"普通母胶9\",\"MaterialLargeCategories\":\"橡胶类\",\"MaterialSmallCategories\":\"再生胶\"},\"EnterSecondLaneWeight\":39.2925},{\"MaterialNo\":\"XJZJ0029\",\"Material\":{\"MaterialNo\":\"XJZJ0029\",\"MaterialName\":\"氧化锌\",\"MaterialSpecification\":\"氧化锌\",\"MaterialLargeCategories\":\"橡胶助剂\",\"MaterialSmallCategories\":\"化合物\"},\"EnterSecondLaneWeight\":2.9548},{\"MaterialNo\":\"XJZJ0028\",\"Material\":{\"MaterialNo\":\"XJZJ0028\",\"MaterialName\":\"硬脂酸\",\"MaterialSpecification\":\"硬脂酸\",\"MaterialLargeCategories\":\"橡胶助剂\",\"MaterialSmallCategories\":\"硫化活性剂\"},\"EnterSecondLaneWeight\":1.8441},{\"MaterialNo\":\"XJZJ0082\",\"Material\":{\"MaterialNo\":\"XJZJ0082\",\"MaterialName\":\"橡胶防老剂RD(TMQ)\",\"MaterialSpecification\":\"防老剂RD(TMQ)\",\"MaterialLargeCategories\":\"橡胶助剂\",\"MaterialSmallCategories\":\"橡胶防老剂\"},\"EnterSecondLaneWeight\":1.4774},{\"MaterialNo\":\"XJZJ0031\",\"Material\":{\"MaterialNo\":\"XJZJ0031\",\"MaterialName\":\"古马隆\",\"MaterialSpecification\":\"古马隆\",\"MaterialLargeCategories\":\"橡胶助剂\",\"MaterialSmallCategories\":\"化合物\"},\"EnterSecondLaneWeight\":5.8991},{\"MaterialNo\":\"XJZJ0030\",\"Material\":{\"MaterialNo\":\"XJZJ0030\",\"MaterialName\":\"碳酸钙\",\"MaterialSpecification\":\"碳酸钙\",\"MaterialLargeCategories\":\"橡胶助剂\",\"MaterialSmallCategories\":\"化合物\"},\"EnterSecondLaneWeight\":26.7189},{\"MaterialNo\":\"XJZJ0066\",\"Material\":{\"MaterialNo\":\"XJZJ0066\",\"MaterialName\":\"炭黑N660\",\"MaterialSpecification\":\"炭黑N660\",\"MaterialLargeCategories\":\"橡胶助剂\",\"MaterialSmallCategories\":\"橡胶补强剂\"},\"EnterSecondLaneWeight\":38.7162},{\"MaterialNo\":\"XJZJ0059\",\"Material\":{\"MaterialNo\":\"XJZJ0059\",\"MaterialName\":\"白炭黑\",\"MaterialSpecification\":\"白炭黑\",\"MaterialLargeCategories\":\"橡胶助剂\",\"MaterialSmallCategories\":\"橡胶补强剂\"},\"EnterSecondLaneWeight\":11.0543},{\"MaterialNo\":\"XJZJ0040\",\"Material\":{\"MaterialNo\":\"XJZJ0040\",\"MaterialName\":\"芳烃油\",\"MaterialSpecification\":\"芳烃油\",\"MaterialLargeCategories\":\"橡胶助剂\",\"MaterialSmallCategories\":\"化合物\"},\"EnterSecondLaneWeight\":15.4027},{\"MaterialNo\":\"\",\"Material\":{\"MaterialNo\":\"\",\"MaterialName\":\"\",\"MaterialSpecification\":\"\",\"MaterialLargeCategories\":\"\",\"MaterialSmallCategories\":\"\"},\"EnterSecondLaneWeight\":0},{\"MaterialNo\":\"\",\"Material\":{\"MaterialNo\":\"\",\"MaterialName\":\"\",\"MaterialSpecification\":\"\",\"MaterialLargeCategories\":\"\",\"MaterialSmallCategories\":\"\"},\"EnterSecondLaneWeight\":0}],\"MaterialList_2\":[{\"MaterialNo\":\"XJZJ0093\",\"Material\":{\"MaterialNo\":\"XJZJ0093\",\"MaterialName\":\"硫磺\",\"MaterialSpecification\":\"硫磺\",\"MaterialLargeCategories\":\"橡胶助剂\",\"MaterialSmallCategories\":\"矿物质\"},\"ProductionRequiresWeight\":3.9893},{\"MaterialNo\":\"XJZJ0070\",\"Material\":{\"MaterialNo\":\"XJZJ0070\",\"MaterialName\":\"促进剂CBS(CZ)\",\"MaterialSpecification\":\"促进剂CBS(CZ)\",\"MaterialLargeCategories\":\"橡胶助剂\",\"MaterialSmallCategories\":\"橡胶促进剂\"},\"ProductionRequiresWeight\":1.6034},{\"MaterialNo\":\"XJZJ0071\",\"Material\":{\"MaterialNo\":\"XJZJ0071\",\"MaterialName\":\"促进剂MBTS(DM)\",\"MaterialSpecification\":\"促进剂MBTS(DM)\",\"MaterialLargeCategories\":\"橡胶助剂\",\"MaterialSmallCategories\":\"橡胶促进剂\"},\"ProductionRequiresWeight\":0.4199},{\"MaterialNo\":\"XJZJ0055\",\"Material\":{\"MaterialNo\":\"XJZJ0055\",\"MaterialName\":\"橡胶黏合剂AS-88(AB-30)\",\"MaterialSpecification\":\"AB-30\",\"MaterialLargeCategories\":\"橡胶助剂\",\"MaterialSmallCategories\":\"橡胶黏合剂\"},\"ProductionRequiresWeight\":6.3562},{\"MaterialNo\":\"\",\"Material\":{\"MaterialNo\":\"\",\"MaterialName\":\"\",\"MaterialSpecification\":\"\",\"MaterialLargeCategories\":\"\",\"MaterialSmallCategories\":\"\"},\"ProductionRequiresWeight\":0},{\"MaterialNo\":\"\",\"Material\":{\"MaterialNo\":\"\",\"MaterialName\":\"\",\"MaterialSpecification\":\"\",\"MaterialLargeCategories\":\"\",\"MaterialSmallCategories\":\"\"},\"ProductionRequiresWeight\":0}],\"AfterPromotionTotalWeight\":210.0885},\"LargeClothGlueCoefficient\":1.279,\"LargeClothGlueUsage\":1724.3264,\"BufferGlueUsage\":1176.68,\"MiddleGlue\":{\"MaterialList_1\":\"\",\"MaterialList_2\":\"\",\"AfterPromotionTotalWeight\":\"\"},\"MiddleGlueCoefficient\":0,\"MiddleGlueUsage\":0,\"SmallBarWidth\":300,\"SmallBarThickness\":0,\"SmallBarStandardUsage\":0,\"FormingArea\":2000,\"RollCoatingArea\":2133.3333,\"RolledFabricArea\":2000,\"SulfurizationArea\":4133.3333,\"LargeClothArea\":2014.4,\"SmallClothArea\":0,\"BeltTotalArea\":4133.3333,\"SkirtArea\":0,\"PartitionArea\":0,\"EdgeBandingTotalArea\":4133.3333,\"WireropeBeltTotalArea\":1520,\"OrderDate\":\"2024/6/13 0:00:00\",\"DeliveryDate\":\"2024/5/31 0:00:00\",\"SeqNo\":\"SCRW00020907\",\"ProductType\":\"承包\",\"ProductStatus\":\"待生产\",\"OrderOwner\":\"福建信明 XDLS20240624\",\"CustomerInfo\":\"沙钢（八车间剩余价值皮带） 承包  K501 SCJH00005709\",\"BeltLengthSpecifications\":\"EP300输送带 1600*5(6+2) 250米\",\"AreaAndWeight\":\"面积：4133.3333 重量：7277.49\",\"UsingRawMaterials\":\"布： EP300 1259 米 胶：14# + P芯胶（普通大布胶）\"}],\"result\":\"success\",\"message\":\"\"},\"DataType\":0}";
            // 处理接口返回消息
            ObjectMapper resultMapper = new ObjectMapper();
            // 将 JSON 字符串转换为 Java 对象
            ResponseData data = resultMapper.readValue(result, ResponseData.class);
            List<RecordData> dataList = data.getReturnData().getData();
            for (RecordData recordData : dataList) {
                ProdOrderDetail orderDetail = orderInfoService.insertOrderByERP(recordData);
                resultList.add(orderDetail);
            }
            logger.warn("获取ERP订单成功:" + requestParam + "|" + result);
        } catch (JsonProcessingException e) {
            logger.warn("获取ERP订单异常:" + requestParam + "|" + result + "|" + e);
        }

        return resultList;
    }


    /**
     * 获取员工工资系数
     * @param paramDto
     * @return
     */
    @Override
    public List<BaseStaffInfo> getERPEmployeeWageData(ERPParamDto paramDto) {
        List<BaseStaffInfo> resultList = new ArrayList<>();
        String requestParam = null;
        String result = null;
        try {
            // 创建ObjectMapper实例 对象转JSON字符串
            ObjectMapper objectMapper = new ObjectMapper();
            objectMapper.setPropertyNamingStrategy(PropertyNamingStrategy.UPPER_CAMEL_CASE);
            requestParam = objectMapper.writeValueAsString(paramDto);
            result = ApiUtils.sendERPHttpPost(ERPConstants.ERP_URL, requestParam);
            // 处理接口返回消息
            ObjectMapper resultMapper = new ObjectMapper();
            // 将 JSON 字符串转换为 Java 对象
            HashMap hashMap = resultMapper.readValue(result, HashMap.class);
            HashMap returnData = (HashMap)hashMap.get("ReturnData");
            List<HashMap<String, String>> dataList = (List<HashMap<String, String>>)returnData.get("data");
            for (HashMap<String, String> data : dataList) {
                BaseStaffInfo baseStaffInfo = staffInfoService.insertStaffByERP(data);
                resultList.add(baseStaffInfo);
            }
            logger.warn("获取员工工资系数成功:" + requestParam + "|" + result);
        } catch (JsonProcessingException e) {
            logger.warn("获取员工工资系数异常:" + requestParam + "|" + result + "|" + e);
        }

        return resultList;
    }

    /**
     * 最新工资系数
     * @param paramDto
     * @return
     */
    @Override
    public LatestSalary getERPLatestSalaryData(ERPParamDto paramDto) {
        LatestSalary latestSalary = null;
        String requestParam = null;
        String result = null;

        if (StringUtils.isEmpty(paramDto.getAppCode())){
            paramDto.setAppCode(ERPConstants.salaryAppCode);
        }
        if (StringUtils.isEmpty(paramDto.getController())){
            paramDto.setController(ERPConstants.salaryController);
        }
        if (StringUtils.isEmpty(paramDto.getActionName())){
            paramDto.setActionName(ERPConstants.salaryActionName);
        }
        try {
            // 创建ObjectMapper实例 对象转JSON字符串
            ObjectMapper objectMapper = new ObjectMapper();
            objectMapper.setPropertyNamingStrategy(PropertyNamingStrategy.UPPER_CAMEL_CASE);
            requestParam = objectMapper.writeValueAsString(paramDto);
            result = ApiUtils.sendERPHttpPost(ERPConstants.ERP_URL, requestParam);
            // 处理接口返回消息
            ObjectMapper resultMapper = new ObjectMapper();
            // 将 JSON 字符串转换为 Java 对象
            HashMap hashMap = resultMapper.readValue(result, HashMap.class);
            HashMap returnData = (HashMap)hashMap.get("ReturnData");
            HashMap<String, Object> data = (HashMap<String, Object>)returnData.get("data");
            latestSalary = resultMapper.readValue(objectMapper.writeValueAsString(data), LatestSalary.class);
        } catch (Exception e) {
            logger.warn("获取最新工资系数异常:" + requestParam + "|" + result + "|" + e);
        }
        return latestSalary;
    }

    /**
     * 新增【薪资明细】
     * @param recordStaffSalary
     * @return
     */
    @Override
    public String addSalaryBreakdown(RecordStaffSalary recordStaffSalary) {
        String objectId = null;//ERP返回数据的ObjectId
        String requestParam = null;
        String result = null;
        ERPStaffSalary erpStaffSalary = new ERPStaffSalary();
        erpStaffSalary.setAppCode(ERPConstants.addSalaryAppCode);
        erpStaffSalary.setController(ERPConstants.addSalaryController);
        erpStaffSalary.setActionName(ERPConstants.addSalaryActionName);
        erpStaffSalary.setIdCard(recordStaffSalary.getIdCard());
        erpStaffSalary.setGroupId(recordStaffSalary.getGroupId());
        erpStaffSalary.setEventDate(recordStaffSalary.getEventDate());
        erpStaffSalary.setSalaryCategory(recordStaffSalary.getSalaryCategory());
        erpStaffSalary.setRevenueClass(recordStaffSalary.getRevenueClass());
        erpStaffSalary.setRevenueAmount(recordStaffSalary.getRevenueAmount());
        erpStaffSalary.setRevenueReason(recordStaffSalary.getRevenueReason());
        try {
            // 创建ObjectMapper实例 对象转JSON字符串
            ObjectMapper objectMapper = new ObjectMapper();
            objectMapper.setPropertyNamingStrategy(PropertyNamingStrategy.UPPER_CAMEL_CASE);
            requestParam = objectMapper.writeValueAsString(erpStaffSalary);
//            result = ApiUtils.sendERPHttpPost(ERPConstants.ERP_URL, requestParam);
            result = "{\n" +
                    "\t\"Successful\": true,\n" +
                    "\t\"ErrorMessage\": null,\n" +
                    "\t\"Logined\": false,\n" +
                    "\t\"ReturnData\": {\n" +
                    "\t\t\"data\": {\n" +
                    "\t\t\t\"ObjectId\": \"25ff81b4-fb0b-4f1c-b9b1-6a2afab1cd0f\"\n" +
                    "\t\t},\n" +
                    "\t\t\"result\": \"success\",\n" +
                    "\t\t\"message\": \"创建成功！\"\n" +
                    "\t},\n" +
                    "\t\"DataType\": 0\n" +
                    "}";
            // 处理接口返回消息
            ObjectMapper resultMapper = new ObjectMapper();
            // 将 JSON 字符串转换为 Java 对象
            HashMap hashMap = resultMapper.readValue(result, HashMap.class);
            HashMap returnData = (HashMap)hashMap.get("ReturnData");
            HashMap<String, Object> data = (HashMap<String, Object>)returnData.get("data");
            objectId = String.valueOf(data.get("ObjectId"));
        } catch (Exception e) {
            logger.warn("新增【薪资明细】异常:" + requestParam + "|" + result + "|" + e);
        }
        return objectId;
    }


}
