package com.os.mes.prod.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.os.common.annotation.Log;
import com.os.common.core.controller.BaseController;
import com.os.common.core.domain.AjaxResult;
import com.os.common.enums.BusinessType;
import com.os.mes.prod.domain.ProdOrderDetail;
import com.os.mes.prod.service.IProdOrderDetailService;
import com.os.common.utils.poi.ExcelUtil;
import com.os.common.core.page.TableDataInfo;

/**
 * 订单明细Controller
 *
 * @author Yinq
 * @date 2024-06-13
 */
@RestController
@RequestMapping("/mes/prod/prodOrderDetail")
public class ProdOrderDetailController extends BaseController {
    @Autowired
    private IProdOrderDetailService prodOrderDetailService;

    /**
     * 查询订单明细列表
     */
    @PreAuthorize("@ss.hasPermi('mes/prod:prodOrderDetail:list')")
    @GetMapping("/list")
    public TableDataInfo list(ProdOrderDetail prodOrderDetail) {
        startPage();
        List<ProdOrderDetail> list = prodOrderDetailService.selectProdOrderDetailList(prodOrderDetail);
        return getDataTable(list);
    }

    /**
     * 导出订单明细列表
     */
    @PreAuthorize("@ss.hasPermi('mes/prod:prodOrderDetail:export')")
    @Log(title = "订单明细", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ProdOrderDetail prodOrderDetail) {
        List<ProdOrderDetail> list = prodOrderDetailService.selectProdOrderDetailList(prodOrderDetail);
        ExcelUtil<ProdOrderDetail> util = new ExcelUtil<ProdOrderDetail>(ProdOrderDetail.class);
        util.exportExcel(response, list, "订单明细数据");
    }

    /**
     * 获取订单明细详细信息
     */
    @PreAuthorize("@ss.hasPermi('mes/prod:prodOrderDetail:query')")
    @GetMapping(value = "/{objId}")
    public AjaxResult getInfo(@PathVariable("objId") Long objId) {
        return success(prodOrderDetailService.selectProdOrderDetailByObjId(objId));
    }

    /**
     * 新增订单明细
     */
    @PreAuthorize("@ss.hasPermi('mes/prod:prodOrderDetail:add')")
    @Log(title = "订单明细", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ProdOrderDetail prodOrderDetail) {
        return toAjax(prodOrderDetailService.insertProdOrderDetail(prodOrderDetail));
    }

    /**
     * 修改订单明细
     */
    @PreAuthorize("@ss.hasPermi('mes/prod:prodOrderDetail:edit')")
    @Log(title = "订单明细", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ProdOrderDetail prodOrderDetail) {
        return toAjax(prodOrderDetailService.updateProdOrderDetail(prodOrderDetail));
    }

    /**
     * 删除订单明细
     */
    @PreAuthorize("@ss.hasPermi('mes/prod:prodOrderDetail:remove')")
    @Log(title = "订单明细", businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}")
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(prodOrderDetailService.deleteProdOrderDetailByObjIds(objIds));
    }
}
